@@ -49,15 +49,15 @@
 //   during lookup, the non prefix version is also recognized.
 
 // The "place_holder" field in Entry and the "Vector<int>" parameter of
-// commit_all are there to deal with the fact that with spacing
-// options on the command line such as "--key what" it cannot be
-// determined if "what" should be a value of "key" or if it should
+// commit_all are there to deal with the fact than when spacing
+// options on the command line such as "--key what" it can not be
+// determined if "what" should be a the value of "key" or if it should
 // be treated as an independent arg.  This is because "key" may
 // be a filter option.  Filter options KeyInfo are not loaded until
 // after a commit which is not done at the time the options are being
 // read in from the command line.  (If the command line arguments are
-// read in after the other settings are read in and committed, then any
-// options setting any of the config files will be ignored.  Thus, the
+// read in after the other settings are read in and committed than any
+// options setting any of the config files will be ignored.  Thus the
 // command line must be parsed and options must be added in an
 // uncommitted state).  So the solution is to assume it is an
 // independent arg until told otherwise, the position in the arg array
@@ -324,16 +324,6 @@ namespace acommon {
     return cur ? cur->value : get_default(ki);
   }
 
-  PosibErr<Config::Value> Config::retrieve_value(ParmStr key) const
-  {
-    RET_ON_ERR_SET(keyinfo(key), const KeyInfo *, ki);
-    if (ki->type == KeyInfoList) return make_err(key_not_string, ki->name);
-
-    const Entry * cur = lookup(ki->name);
-
-    return cur ? Value(cur->value,cur->secure) : Value(get_default(ki), true);
-  }
-  
   PosibErr<String> Config::retrieve_any(ParmStr key) const
   {
     RET_ON_ERR_SET(keyinfo(key), const KeyInfo *, ki);
@@ -384,12 +374,9 @@ namespace acommon {
     return atoi(value.str());
   }
 
-#define RET_ON_ERR_WRAP(prefix, key, cmd)                                \
-  do{PosibErrBase pe(cmd);if(pe.has_err())return pe.with_key(prefix, strncmp(key, "f-", 2) == 0 ? key + 2 : key);}while(false)
-
-  PosibErr<void> Config::lookup_list(const KeyInfo * ki,
-                                     MutableContainer & m,
-                                     bool include_default) const
+  void Config::lookup_list(const KeyInfo * ki,
+                           MutableContainer & m,
+                           bool include_default) const
   {
     const Entry * cur = first_;
     const Entry * first_to_use = 0;
@@ -419,7 +406,7 @@ namespace acommon {
 
     if (cur && cur->action == Set) {
       if (!include_default) m.clear();
-      RET_ON_ERR_WRAP("", ki->name, m.add(cur->value));
+      m.add(cur->value);
       cur = cur->next;
     }
 
@@ -431,24 +418,21 @@ namespace acommon {
     while (cur) {
       if (cur->key == ki->name) {
         if (cur->action == ListAdd)
-          RET_ON_ERR_WRAP("add-", ki->name, m.add(cur->value));
+          m.add(cur->value);
         else if (cur->action == ListRemove)
-          RET_ON_ERR_WRAP("remove-", ki->name, m.remove(cur->value));
+          m.remove(cur->value);
       }
       cur = cur->next;
     }
-    return no_err;
   }
 
-#undef RET_ON_ERR_WRAP
-
   PosibErr<void> Config::retrieve_list(ParmStr key, 
 				       MutableContainer * m) const
   {
     RET_ON_ERR_SET(keyinfo(key), const KeyInfo *, ki);
     if (ki->type != KeyInfoList) return make_err(key_not_list, ki->name);
 
-    RET_ON_ERR(lookup_list(ki, *m, true));
+    lookup_list(ki, *m, true);
 
     return no_err;
   }
@@ -805,7 +789,6 @@ namespace acommon {
     Entry * entry = new Entry;
     entry->key = key;
     entry->value = value;
-    entry->secure = true;
     return set(entry);
   }
   
@@ -1320,16 +1303,16 @@ namespace acommon {
   PosibErr<void> Config::commit_all(Vector<int> * phs, const char * codeset)
   {
     committed_ = true;
-    Entry * uncommitted = first_;
+    Entry * uncommited = first_;
     first_ = 0;
     insert_point_ = &first_;
     Conv to_utf8;
     if (codeset)
       RET_ON_ERR(to_utf8.setup(*this, codeset, "utf-8", NormTo));
     PosibErr<void> ret;
-    while (uncommitted) {
-      Entry * cur = uncommitted;
-      uncommitted = cur->next;
+    while (uncommited) {
+      Entry * cur = uncommited;
+      uncommited = cur->next;
       cur->next = 0;
       *insert_point_ = cur;
       insert_point_ = &((*insert_point_)->next);
@@ -1399,8 +1382,6 @@ namespace acommon {
        N_("filter mode"), KEYINFO_COMMON}
     , {"extra-dicts", KeyInfoList, "",
        N_("extra dictionaries to use")}
-    , {"wordlists", KeyInfoList, "",
-       N_("files with list of extra words to accept")}
     , {"home-dir", KeyInfoString, HOME_DIR,
        N_("location for personal files")}
     , {"ignore",   KeyInfoInt   , "1",
@@ -1457,8 +1438,6 @@ namespace acommon {
        N_("maximum number that can be strung together"), KEYINFO_MAY_CHANGE}
     , {"run-together-min",    KeyInfoInt,   "3",
        N_("minimal length of interior words"), KEYINFO_MAY_CHANGE}
-    , {"camel-case", KeyInfoBool,  "false",
-       N_("consider camel case words legal"), KEYINFO_MAY_CHANGE}
     , {"save-repl", KeyInfoBool  , "true",
        N_("save replacement pairs on save all")}
     , {"set-prefix", KeyInfoBool, "true",
