@@ -23,21 +23,12 @@ namespace acommon {
   class OStream;
   class Config;
 
-  struct ConvKey {
-    ParmString val;
-    bool allow_ucs;
-    ConvKey() : val(), allow_ucs() {}
-    template <typename T>
-    ConvKey(const T & v, bool a = false) : val(v), allow_ucs(a) {}
-  };
-
   struct ConvBase : public Cacheable {
     typedef const Config CacheConfig;
-    typedef ConvKey CacheKey;
+    typedef const char * CacheKey;
     String key;
     int type_width; // type width in bytes
-    bool is_ucs() const {return type_width != 1;}
-    bool cache_key_eq(CacheKey k) const  {return k.allow_ucs ? key == k.val : key == k.val && !is_ucs();}
+    bool cache_key_eq(const char * l) const  {return key == l;}
     ConvBase() : type_width(1) {}
   private:
     ConvBase(const ConvBase &);
@@ -50,7 +41,7 @@ namespace acommon {
 			FilterCharVector & out) const = 0;
     virtual PosibErr<void> decode_ec(const char * in, int size,
                                      FilterCharVector & out, ParmStr orig) const = 0;
-    static PosibErr<Decode *> get_new(const ConvKey &, const Config *);
+    static PosibErr<Decode *> get_new(const String &, const Config *);
     virtual ~Decode() {}
   };
   struct Encode : public ConvBase {
@@ -64,7 +55,7 @@ namespace acommon {
     // may convert inplace
     virtual bool encode(FilterChar * & in, FilterChar * & stop, 
                         FilterCharVector & buf) const {return false;}
-    static PosibErr<Encode *> get_new(const ConvKey &, const Config *);
+    static PosibErr<Encode *> get_new(const String &, const Config *);
     virtual ~Encode() {}
   };
   struct DirectConv { // convert directly from in_code to out_code.
@@ -133,9 +124,9 @@ namespace acommon {
     // this class in any way.
     Filter filter;
 
-    PosibErr<void> init(const Config &, const ConvKey & in, const ConvKey & out);
-    PosibErr<void> init_norm_to(const Config &, const ConvKey & in, const ConvKey & out);
-    PosibErr<void> init_norm_from(const Config &, const ConvKey & in, const ConvKey & out);
+    PosibErr<void> init(const Config &, ParmStr in, ParmStr out);
+    PosibErr<void> init_norm_to(const Config &, ParmStr in, ParmStr out);
+    PosibErr<void> init_norm_from(const Config &, ParmStr in, ParmStr out);
     
     const char * in_code() const   {return decode_->key.c_str();}
     const char * out_code() const  {return encode_->key.c_str();}
@@ -226,19 +217,19 @@ namespace acommon {
   enum Normalize {NormNone, NormFrom, NormTo};
 
   PosibErr<Convert *> internal_new_convert(const Config & c, 
-                                           ConvKey in, ConvKey out,
+                                           ParmString in, ParmString out,
                                            bool if_needed,
                                            Normalize n);
   
   static inline PosibErr<Convert *> new_convert(const Config & c,
-                                                const ConvKey & in, const ConvKey & out,
+                                                ParmStr in, ParmStr out,
                                                 Normalize n)
   {
     return internal_new_convert(c,in,out,false,n);
   }
   
   static inline PosibErr<Convert *> new_convert_if_needed(const Config & c,
-                                                          const ConvKey & in, const ConvKey & out,
+                                                          ParmStr in, ParmStr out,
                                                           Normalize n)
   {
     return internal_new_convert(c,in,out,true,n);
@@ -248,7 +239,7 @@ namespace acommon {
     Convert * ptr;
     ConvObj(Convert * c = 0) : ptr(c) {}
     ~ConvObj() {delete ptr;}
-    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, Normalize norm)
+    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, Normalize norm)
     {
       delete ptr;
       ptr = 0;
@@ -272,7 +263,7 @@ namespace acommon {
     ConvP(const ConvObj & c) : conv(c.ptr) {}
     ConvP(const ConvP & c) : conv(c.conv) {}
     void operator=(const ConvP & c) { conv = c.conv; }
-    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, 
+    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, 
                          Normalize norm)
     {
       delete conv;
@@ -343,7 +334,7 @@ namespace acommon {
   {
     ConvObj conv_obj;
     Conv(Convert * c = 0) : ConvP(c), conv_obj(c) {}
-    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, Normalize norm)
+    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, Normalize norm)
     {
       RET_ON_ERR(conv_obj.setup(c,from,to,norm));
       conv = conv_obj.ptr;
@@ -360,7 +351,7 @@ namespace acommon {
     ConvECP(const ConvObj & c) : conv(c.ptr) {}
     ConvECP(const ConvECP & c) : conv(c.conv) {}
     void operator=(const ConvECP & c) { conv = c.conv; }
-    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, Normalize norm)
+    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, Normalize norm)
     {
       delete conv;
       conv = 0;
@@ -415,7 +406,7 @@ namespace acommon {
   {
     ConvObj conv_obj;
     ConvEC(Convert * c = 0) : ConvECP(c), conv_obj(c) {}
-    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, Normalize norm)
+    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, Normalize norm)
     {
       RET_ON_ERR(conv_obj.setup(c,from,to,norm));
       conv = conv_obj.ptr;
