@@ -1,5 +1,5 @@
 // This file is part of The New Aspell
-// Copyright (C) 2000-2001 by Kevin Atkinson under the GNU LGPL
+// Copyright (C) 2000-2001,2011 by Kevin Atkinson under the GNU LGPL
 // license version 2.0 or 2.1.  You should have received a copy of the
 // LGPL license along with this library if you did not you can find it
 // at http://www.gnu.org/.
@@ -96,7 +96,7 @@ namespace aspeller {
       PosibErr<Language *> res = new_language(config, l);
       if (res.has_err()) return res;
       lang_.reset(res.data);
-      lang_->set_lang_defaults(config);
+      RET_ON_ERR(lang_->set_lang_defaults(config));
       set_lang_hook(config);
     } else {
       if (l != lang_->name())
@@ -415,7 +415,10 @@ namespace aspeller {
 
     res = 0;
 
+    Lock dict_cache_lock(NULL);
+
     if (actual_type == DT_ReadOnly) { // try to get it from the cache
+      dict_cache_lock.set(&dict_cache.lock); 
       res = dict_cache.find(id);
     }
 
@@ -446,12 +449,15 @@ namespace aspeller {
       
       res = w.release();
 
-    } else {
-      
-      res->copy();
+    } else { // actual_type == DT_ReadOnly implied, and hence the lock
+             // is already acquired
+
+      res->copy_no_lock();
       
     }
 
+    dict_cache_lock.release();
+
     if (new_dicts)
       new_dicts->add(res);
     
