@@ -20,7 +20,7 @@
 #include "getdata.hpp"
 #include "file_util.hpp"
 
-#ifdef HAVE_LANGINFO_CODESET
+#ifdef ENABLE_NLS
 #  include <langinfo.h>
 #endif
 
@@ -113,10 +113,7 @@ namespace aspeller {
     name_          = data.retrieve("name");
     charset_       = fix_encoding_str(data.retrieve("charset"), buf);
     charmap_       = charset_;
-
-    ConfigConvKey d_enc = data.retrieve_value("data-encoding");
-    d_enc.fix_encoding_str();
-    data_encoding_ = d_enc.val;
+    data_encoding_ = fix_encoding_str(data.retrieve("data-encoding"), buf);
 
     DataPair d;
 
@@ -428,38 +425,6 @@ namespace aspeller {
     cur->next = 0;
     return cur;
   }
-
-  CompoundWord Language::split_word(const char * word, unsigned len,
-                                    bool camel_case) const
-  {
-    if (!camel_case || len <= 1)
-      return CompoundWord(word, word + len);
-    // len >= 2
-    if (is_upper(word[0])) {
-      if (is_lower(word[1])) {
-        unsigned i = 2;
-        while (i < len && is_lower(word[i]))
-          ++i;
-        return CompoundWord(word, word + i, word + len);
-      }
-      if (is_upper(word[1])) {
-        unsigned i = 2;
-        while (i < len && is_upper(word[i]))
-          ++i;
-        if (i == len)
-          return CompoundWord(word, word + len);
-        // The first upper case letter is assumed to be part of the next word
-        return CompoundWord(word, word + i - 1, word + len);
-      }
-    } else if (is_lower(word[0])) {
-      unsigned i = 1;
-      while (i < len && is_lower(word[i]))
-        ++i;
-      return CompoundWord(word, word + i, word + len);
-    }
-    // this should't happen but just in case...
-    return CompoundWord(word, word + len);
-  }
   
   bool SensitiveCompare::operator() (const char * word0, 
 				     const char * inlist0) const
@@ -519,14 +484,9 @@ namespace aspeller {
     return make_err(invalid_word, MsgConv(l)(word), msg);
   }
 
-  PosibErr<void> check_if_sane(const Language & l, ParmStr word) {
+  PosibErr<void> check_if_valid(const Language & l, ParmStr word) {
     if (*word == '\0') 
       return invalid_word_e(l, word, _("Empty string."));
-    return no_err;
-  }
-
-  PosibErr<void> check_if_valid(const Language & l, ParmStr word) {
-    RET_ON_ERR(check_if_sane(l, word));
     const char * i = word;
     if (!l.is_alpha(*i)) {
       if (!l.special(*i).begin)
@@ -678,7 +638,10 @@ namespace aspeller {
                                    const Language * lang0,
                                    OStream * log0)
     : in(in0), lang(lang0), log(log0), val(), str(0), str_end(0),
-      clean_affix(lang0, log0) {}
+      clean_affix(lang0, log0)
+  {
+    memset(brk, '\0', sizeof(brk));
+  }
 
   PosibErr<void>  WordListIterator::init(Config & config)
   {
@@ -691,28 +654,15 @@ namespace aspeller {
     skip_invalid_words = config.retrieve_bool("skip-invalid-words");
     clean_affixes = config.retrieve_bool("clean-affixes");
     if (config.have("encoding")) {
-      ConfigConvKey enc = config.retrieve_value("encoding");
-      RET_ON_ERR(iconv.setup(config, enc, lang->charmap(),NormFrom));
+      RET_ON_ERR(iconv.setup(config, config.retrieve("encoding"), lang->charmap(),NormFrom));
     } else {
       RET_ON_ERR(iconv.setup(config, lang->data_encoding(), lang->charmap(), NormFrom));
     }
+    brk[0] = ' ';
+    if (!lang->special('-').any) brk[1] = '-';
     return no_err;
   }
 
-  PosibErr<void> WordListIterator::init_plain(Config & config)
-  {
-    if (!config.have("norm-strict"))
-      config.replace("norm-strict", "true");
-    have_affix = false;
-    validate_words = config.retrieve_bool("validate-words");
-    clean_words = true;
-    if (config.have("clean-words"))
-      clean_words = config.retrieve_bool("clean-words");
-    skip_invalid_words = true;
-    RET_ON_ERR(iconv.setup(config, "utf-8", lang->charmap(),NormFrom));
-    return no_err;
-  }
- 
   PosibErr<bool> WordListIterator::adv() 
   {
   loop:
@@ -758,11 +708,15 @@ namespace aspeller {
       val.aff.size = aff_end - aff;
       if (!*aff && validate_words && clean_words) {
         char * s = str;
-        while (s < str_end && !lang->is_alpha(*s) && !lang->special(*s).begin)
-          *s++ = '\0';
-        char * s2 = str_end - 1;
-        while (s2 >= str && *s2 && !lang->is_alpha(*s2) && !lang->special(*s2).end)
-          *s2-- = '\0';
+        while (s < str_end) {
+          while (s < str_end && !lang->is_alpha(*s) && !lang->special(*s).begin)
+            *s++ = '\0';
+          s += strcspn(s, brk);
+          *s = '\0';
+          char * s2 = s - 1;
+          while (s2 >= str && *s2 && !lang->is_alpha(*s2) && !lang->special(*s2).end)
+            *s2-- = '\0';
+        }
       }
     }
     while (str < str_end) 
