@@ -6,7 +6,6 @@
 #include "word_list.hpp"
 #include "enumeration.hpp"
 #include "parm_string.hpp"
-#include "suggestions.hpp"
 
 using namespace acommon;
 
@@ -21,8 +20,8 @@ namespace aspeller {
     typedef const char *               Value;
     typedef unsigned int               Size;
 
-    //virtual SuggestionList * clone() const = 0;
-    //virtual void assign(const SuggestionList *) = 0;
+    virtual SuggestionList * clone() const = 0;
+    virtual void assign(const SuggestionList *) = 0;
     
     virtual bool empty() const = 0;
     virtual Size size() const = 0;
@@ -34,12 +33,10 @@ namespace aspeller {
   public:
     virtual PosibErr<void> set_mode(ParmString) = 0;
     virtual SuggestionList & suggest(const char * word) = 0;
-    virtual SuggestionsData & suggestions(const char * word) = 0;
     virtual ~Suggest() {}
   };
-
+  
   PosibErr<Suggest *> new_default_suggest(SpellerImpl *);
-
 }
 
 
