@@ -102,13 +102,10 @@ protected:
   
   String compatibility_file_name;
     
-  WritableBase(BasicType t, const char * n, const char * s, const char * cs, const Config & cfg)
+  WritableBase(BasicType t, const char * n, const char * s, const char * cs)
     : Dictionary(t,n),
       suffix(s), compatibility_suffix(cs),
-      use_soundslike(true) {
-    fast_lookup = true;
-    validate_words = cfg.retrieve_bool("validate-words");
-  }
+      use_soundslike(true) {fast_lookup = true;}
   virtual ~WritableBase() {}
   
   virtual PosibErr<void> save(FStream &, ParmString) = 0;
@@ -190,8 +187,8 @@ PosibErr<void> WritableBase::load(ParmString f0, Config & config,
 PosibErr<void> WritableBase::merge(ParmString f0) {
   FStream in;
   Dict::FileName fn(f0);
-  RET_ON_ERR(open_file_readlock(in, fn.path()));
-  RET_ON_ERR(merge(in, fn.path()));
+  RET_ON_ERR(open_file_readlock(in, fn.path));
+  RET_ON_ERR(merge(in, fn.path));
   return no_err;
 }
 
@@ -387,8 +384,7 @@ public: //but don't use
 
 public:
 
-  WritableDict(const Config & cfg)
-    : WritableBase(basic_dict, "WritableDict", ".pws", ".per", cfg) {}
+  WritableDict() : WritableBase(basic_dict, "WritableDict", ".pws", ".per") {}
 
   Size   size()     const;
   bool   empty()    const;
@@ -504,10 +500,7 @@ WritableDict::Enum * WritableDict::detailed_elements() const {
 }
 
 PosibErr<void> WritableDict::add(ParmString w, ParmString s) {
-  if (validate_words)
-    RET_ON_ERR(check_if_valid(*lang(),w));
-  else
-    RET_ON_ERR(check_if_sane(*lang(),w));
+  RET_ON_ERR(check_if_valid(*lang(),w));
   SensitiveCompare c(lang());
   WordEntry we;
   if (WritableDict::lookup(w,&c,we)) return no_err;
@@ -578,27 +571,16 @@ PosibErr<void> WritableDict::merge(FStream & in,
   return no_err;
 }
 
-struct CStrLess {
-  bool operator() (const char * x, const char * y) const {
-    return strcmp(x, y) < 0;
-  }
-};
-
 PosibErr<void> WritableDict::save(FStream & out, ParmString file_name) 
 {
   out.printf("personal_ws-1.1 %s %i %s\n", 
              lang_name(), word_lookup->size(), file_encoding.c_str());
 
-  Vector<const char *> words;
-  words.reserve(word_lookup->size());
-  for (WordLookup::const_iterator i = word_lookup->begin(), e = word_lookup->end();
-       i != e; ++i)
-    words.push_back(*i);
-  std::sort(words.begin(), words.end(), CStrLess());
+  WordLookup::const_iterator i = word_lookup->begin();
+  WordLookup::const_iterator e = word_lookup->end();
     
   ConvP conv(oconv);
-  for (Vector<const char *>::const_iterator i = words.begin(), e = words.end();
-       i != e; ++i) {
+  for (;i != e; ++i) {
     write_n_escape(out, conv(*i));
     out << '\n';
   }
@@ -621,8 +603,7 @@ class WritableReplDict : public WritableBase
   WritableReplDict& operator=(const WritableReplDict&);
 
 public:
-  WritableReplDict(const Config & cfg)
-    : WritableBase(replacement_dict, "WritableReplDict", ".prepl",".rpl", cfg) 
+  WritableReplDict() : WritableBase(replacement_dict, "WritableReplDict", ".prepl",".rpl") 
   {
     fast_lookup = true;
   }
@@ -837,23 +818,16 @@ PosibErr<void> WritableReplDict::save (FStream & out, ParmString file_name)
 {
   out.printf("personal_repl-1.1 %s 0 %s\n", lang_name(), file_encoding.c_str());
   
-  Vector<const char *> words;
-  words.reserve(word_lookup->size());
-  for (WordLookup::const_iterator i = word_lookup->begin(), e = word_lookup->end();
-       i != e; ++i)
-    words.push_back(*i);
-  std::sort(words.begin(), words.end(), CStrLess());
+  WordLookup::iterator i = word_lookup->begin();
+  WordLookup::iterator e = word_lookup->end();
 
   ConvP conv1(oconv);
   ConvP conv2(oconv);
-
-  Vector<const char *> v;
-  for (Vector<const char *>::const_iterator i = words.begin(), e = words.end();
-       i != e; ++i) 
+  
+  for (;i != e; ++i) 
   {
-    v = *get_vector(*i); // make a copy
-    std::sort(v.begin(), v.end(), CStrLess());
-    for (StrVector::iterator j = v.begin(); j != v.end(); ++j)
+    StrVector * v = get_vector(*i);
+    for (StrVector::iterator j = v->begin(); j != v->end(); ++j)
     {
       write_n_escape(out, conv1(*i));
       out << ' ';
@@ -956,12 +930,12 @@ WritableReplDict::~WritableReplDict()
 
 namespace aspeller {
 
-  Dictionary * new_default_writable_dict(const Config & cfg) {
-    return new WritableDict(cfg);
+  Dictionary * new_default_writable_dict() {
+    return new WritableDict();
   }
 
-  Dictionary * new_default_replacement_dict(const Config & cfg) {
-    return new WritableReplDict(cfg);
+  Dictionary * new_default_replacement_dict() {
+    return new WritableReplDict();
   }
 
 }
