@@ -1,8 +1,8 @@
 // This file is part of The New Aspell Copyright (C)
-// 2002,2003,2004,2011,2019,2023,2026 by Kevin Atkinson
-// under the GNU LGPL license version 2.0 or 2.1.  You should have received a
-// copy of the LGPL license along with this library if you did not you can
-// find it at http://www.gnu.org/.
+// 2002,2003,2004,2011,2019 by Kevin Atkinson under the GNU LGPL license
+// version 2.0 or 2.1.  You should have received a copy of the LGPL
+// license along with this library if you did not you can find it at
+// http://www.gnu.org/.
 
 //
 // NOTE: This program currently uses a very ugly mix of the internal
@@ -52,7 +52,6 @@
 #include "string_enumeration.hpp"
 #include "string_map.hpp"
 #include "word_list.hpp"
-#include "istream_enumeration.hpp"
 
 #include "string_list.hpp"
 #include "speller_impl.hpp"
@@ -205,11 +204,10 @@ static const ModeAbrv mode_abrvs[] = {
   {'e', "mode=email", N_("enter Email mode.")},
   {'H', "mode=html",  N_("enter HTML mode.")},
   {'t', "mode=tex",   N_("enter TeX mode.")},
-  {'n', "mode=nroff", N_("enter Nroff mode.")},
-  {'M', "mode=markdown", N_("enter Markdown mode.")},
+  {'n', "mode=nroff", N_("enter Nroff mode.")}
 };
 
-static const ModeAbrv *  mode_abrvs_end = mode_abrvs + sizeof(mode_abrvs)/sizeof(ModeAbrv);
+static const ModeAbrv *  mode_abrvs_end = mode_abrvs + 4;
 
 const PossibleOption * find_option(char c) {
   const PossibleOption * i = possible_options;
@@ -319,7 +317,7 @@ int main (int argc, const char *argv[])
       if (o->num_arg == 0) {
         num_parms = 0;
 	if (parm[0] != '\0') {
-	  print_error(_("'%s' does not take any parameters."),
+	  print_error(_(" does not take any parameters."), 
 		      String(argv[i], parm - argv[i]));
 	  return 1;
 	}
@@ -677,7 +675,7 @@ void status_fun(void * d, Token, int correct)
     if (ci->compound)
       COUT.put("-\n");
     else if (ci->pre_flag || ci->suf_flag)
-      COUT.printf("+ %s\n", p->oconv(ci->word.str, ci->word.len));
+      COUT.printf("+ %s\n", p->oconv(ci->word.str()));
     else
       COUT.put("*\n");
   }
@@ -757,7 +755,6 @@ void pipe()
       buf.push_back(static_cast<char>(c));
     buf.push_back('\n'); // always add new line so strlen > 0
     buf.push_back('\0');
-    //CERR.printf("%s", buf.data());
     line = buf.data();
     ignore = 0;
     switch (line[0]) {
@@ -876,15 +873,14 @@ void pipe()
           guess.clear();
           if (ci->pre_add && ci->pre_add[0])
             guess.append(ci->pre_add, ci->pre_add_len).append('+');
-          guess.append(ci->word.str, ci->word.len);
+          guess.append(ci->word);
           if (ci->pre_strip_len > 0) 
-            guess.append('-').append(ci->word.str, ci->pre_strip_len);
+            guess.append('-').append(ci->word.str(), ci->pre_strip_len);
           if (ci->suf_strip_len > 0) 
-            guess.append('-').append(ci->word.str + ci->word.len - ci->suf_strip_len, 
+            guess.append('-').append(ci->word.str() + ci->word.size() - ci->suf_strip_len, 
                                      ci->suf_strip_len);
           if (ci->suf_add && ci->suf_add[0])
             guess.append('+').append(ci->suf_add, ci->suf_add_len);
-          guess.ensure_null_end();
           real_speller->lang().fix_case(casep, guess.data(), guess.data());
           guesses << ", " << oconv(guess.str());
           ci = ci->next;
@@ -1447,6 +1443,24 @@ void print_ver () {
 // module
 //
 
+class IstreamEnumeration : public StringEnumeration {
+  FStream * in;
+  String data;
+public:
+  IstreamEnumeration(FStream & i) : in(&i) {}
+  IstreamEnumeration * clone() const {
+    return new IstreamEnumeration(*this);
+  }
+  void assign (const StringEnumeration * other) {
+    *this = *static_cast<const IstreamEnumeration *>(other);
+  }
+  Value next() {
+    if (!in->getline(data)) return 0;
+    else return data.c_str();
+  }
+  bool at_end() const {return *in;}
+};
+
 ///////////////////////////
 //
 // clean
@@ -1594,7 +1608,7 @@ void personal () {
     // FIXME: This is currently broken
 
     Config * config = options;
-    Dictionary * per = new_default_writable_dict(*config);
+    Dictionary * per = new_default_writable_dict();
     EXIT_ON_ERR(per->load(config->retrieve("personal-path"), *config));
     StackPtr<WordEntryEnumeration> els(per->detailed_elements());
     StackPtr<Convert> conv(setup_conv(per->lang(), config));
@@ -1656,7 +1670,7 @@ void repl() {
 
     // FIXME: This is currently broken
 
-    ReplacementDict * repl = new_default_replacement_dict(*options);
+    ReplacementDict * repl = new_default_replacement_dict();
     repl->load(options->retrieve("repl-path"), *options);
     StackPtr<WordEntryEnumeration> els(repl->detailed_elements());
     
@@ -1720,7 +1734,7 @@ void munch()
     COUT << word;
     for (const aspeller::CheckInfo * ci = gi.head; ci; ci = ci->next)
     {
-      COUT << ' ' << oconv(ci->word.str, ci->word.len) << '/';
+      COUT << ' ' << oconv(ci->word) << '/';
       if (ci->pre_flag != 0) COUT << oconv(static_cast<char>(ci->pre_flag));
       if (ci->suf_flag != 0) COUT << oconv(static_cast<char>(ci->suf_flag));
     }
@@ -1991,7 +2005,7 @@ void munch_list_simple()
     while (ci)
     { {
       // check if the base word is in the dictionary
-      SML_Table::iterator b = table.find(ci->word.str);
+      SML_Table::iterator b = table.find(ci->word);
       if (b == table.end()) goto cont;
 
       // check if all the words once expanded are in the dictionary
@@ -2001,15 +2015,15 @@ void munch_list_simple()
       if (ci->pre_flag != 0) flags += ci->pre_flag;
       if (ci->suf_flag != 0) flags += ci->suf_flag;
       exp_buf.reset();
-      exp_list = lang->expand(ci->word.str, flags, exp_buf);
+      exp_list = lang->expand(ci->word, flags, exp_buf);
       for (WordAff * q = exp_list; q; q = q->next) {
         if (!table.have(q->word)) goto cont;
       }
 
       // the base word and flags are valid, now keep the one with the
       // smallest base word
-      if (ci->word.len < min_base_size) {
-        min_base_size = ci->word.len;
+      if (ci->word.size() < min_base_size) {
+        min_base_size = ci->word.size();
         best = ci;
       }
 
@@ -2019,7 +2033,7 @@ void munch_list_simple()
     // now add the base to the keep list if one exists
     // otherwise just keep the original word
     if (best) {
-      SML_Table::iterator b = table.find(best->word.str);
+      SML_Table::iterator b = table.find(best->word);
       assert(b != table.end());
       if (best->pre_flag) add_affix(b, best->pre_flag);
       if (best->suf_flag) add_affix(b, best->suf_flag);
@@ -2352,7 +2366,7 @@ void munch_list_complete(bool multi, bool simplify)
     while (ci)
     { {
       // check if the base word is in the dictionary
-      CML_Table::iterator b = table.find(ci->word.str);
+      CML_Table::iterator b = table.find(ci->word);
       if (b == table.end()) goto cont;
 
       // check if all the words once expanded are in the dictionary
@@ -2362,7 +2376,7 @@ void munch_list_complete(bool multi, bool simplify)
       else if (ci->suf_flag != 0) flags[0] = ci->suf_flag;
       flags[1] = '\0';
       exp_buf.reset();
-      exp_list = lang->expand(ci->word.str, flags, exp_buf);
+      exp_list = lang->expand(ci->word, flags, exp_buf);
       for (WordAff * q = exp_list; q; q = q->next) {
         if (!table.have(q->word)) goto cont;
       }
@@ -2385,7 +2399,7 @@ void munch_list_complete(bool multi, bool simplify)
 
   // If a base word has both prefixes and suffixes try to combine them.
   // This can lead to multiple entries for the same base word.  If "multi"
-  // is true, then include all the entries.  Otherwise, only include the
+  // is true than include all the entries.  Otherwise, only include the
   // one with the largest number of expansions.  This is a greedy choice
   // that may not be optimal, but is close to it.
   p = table.begin();
@@ -2810,12 +2824,7 @@ void print_help_line(char abrv, char dont_abrv, const char * name,
   if (type == KeyInfoInt)
     command += "=<int>";
   const char * tdesc = _(desc);
-  char buf[120];
-  int len = snprintf(buf, 120, "  %-27s", command.c_str());
-  if (len == 29)
-    printf("%s %s\n", buf, tdesc);
-  else
-    printf("%s\n%30s%s\n", buf, "", tdesc);
+  printf("  %-27s %s\n", command.c_str(), tdesc); // FIXME: consider word wrapping
 }
 
 namespace acommon {
@@ -2881,9 +2890,9 @@ static const unsigned help_text_size = sizeof(help_text)/sizeof(const char *);
 void print_help (bool verbose) {
   load_all_filters(options);
   if (verbose) {
-    printf("\n"
-           "Aspell %s.  Copyright 2000-2026 by Kevin Atkinson.\n"
-           "\n", aspell_version_string());
+    printf(_("\n"
+             "Aspell %s.  Copyright 2000-2011 by Kevin Atkinson.\n"
+             "\n"), aspell_version_string());
     for (unsigned i = 0; i < help_text_size; ++i)
       puts(gt_(help_text[i]));
   } else {
